summaryrefslogtreecommitdiffstats
path: root/juk/keydialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/keydialog.h')
-rw-r--r--juk/keydialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/juk/keydialog.h b/juk/keydialog.h
index 83c14d9d..41a1c6d1 100644
--- a/juk/keydialog.h
+++ b/juk/keydialog.h
@@ -30,9 +30,9 @@ class KeyDialog : public KDialogBase
public:
/**
* Constructs a KeyDialog called @p name as a child of @p tqparent.
*/
- KeyDialog(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *tqparent = 0, const char* name = 0);
+ KeyDialog(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *parent = 0, const char* name = 0);
/**
* Destructor. Deletes all resources used by a KeyDialog object.
@@ -44,7 +44,7 @@ public:
* accelerators and actions. It behaves essentially like the functions
* in KKeyDialog.
*/
- static int configure(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *tqparent = 0);
+ static int configure(KGlobalAccel *keys, KActionCollection *actionCollection, TQWidget *parent = 0);
/**
* This is a member function, provided to create a global accelerator with
@@ -30,9 +30,9 @@ class KeyDialog : public KDialogBase
public:
/**
- * Constructs a KeyDialog called @p name as a child of @p tqparent.
+ * Constructs a KeyDialog called @p name as a child of @p parent.
*/